==> hlw-core-0.0.2-20250904.011858-147-sources.jar: cn/gtmap/hlw/core/constant/pzx/SqxxPzxKeyConstant.java <==
package cn.gtmap.hlw.core.constant.pzx;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/19 10:56
 * @description 申请信息配置项
 */
public class SqxxPzxKeyConstant {

    /**
     * 可删除的SLTZ
     */
    public static final String APPLY_DELETE_SLZT = "apply.delete.slzt";

    /**
     * 是否分别持证
     */
    public static final String SQXX_SFFBCZ = "sqxx.sffbcz";

    /**
     * 申请信息合同信息保存时，需要去除权利人（买方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_HTXX_SAVA_REMOVE_QLR_SQLX = "sqxx.htxx.save.remove.qlr.sqlx";
    /**
     * 申请信息合同信息保存时，需要去除义务人（卖方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_HTXX_SAVA_REMOVE_YWR_SQLX = "sqxx.htxx.save.remove.ywr.sqlx";

    /**
     * 申请信息产权信息保存时，需要去除权利人（买方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_CQXX_SAVA_REMOVE_QLR_SQLX = "sqxx.cqxx.save.remove.qlr.sqlx";
    /**
     * 申请信息产权信息保存时，需要去除义务人（卖方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_CQXX_SAVA_REMOVE_YWR_SQLX = "sqxx.cqxx.save.remove.ywr.sqlx";

    /**
     * 申请信息台账受理状态--待提交
     */
    public static final String SQXX_TZ_DTJ_SLZT = "sqxx.tz.dtj.slzt";
    /**
     * 申请信息台账受理状态--待缴费
     */
    public static final String SQXX_TZ_DJF_SLZT = "sqxx.tz.djf.slzt";
    /**
     * 申请信息台账受理状态--草稿
     */
    public static final String SQXX_TZ_CG_SLZT = "sqxx.tz.cg.slzt";
    /**
     * 申请信息台账受理状态--审核中
     */
    public static final String SQXX_TZ_SHZ_SLZT = "sqxx.tz.shz.slzt";
    /**
     * 申请信息审核通过台账受理状态
     */
    public static final String SQXX_TZ_SHTG_SLZT = "sqxx.tz.shtg.slzt";
    /**
     * 复核工作量查询台账受理状态
     */
    public static final String SQXX_TZ_FHGZL_SLZT = "sqxx.tz.fhgzl.slzt";
    /**
     * 登记资料查询申请台账受理状态
     */
    public static final String SQXX_TZ_DJZLCXSQ_SLZT = "sqxx.tz.djzlcxsq.slzt";
    /**
     * 镇江盖章台账-不需要云签的sqlx
     */
    public static final String SQXX_TZ_NOTYQ_SQLX = "sqxx.tz.notyq.sqlx";
    /**
     * 银行核验台账申请类型
     */
    public static final String SQXX_TZ_YHHY_SQLX = "sqxx.tz.yhhy.sqlx";
    /**
     * 申请信息台账受理状态--已退回
     */
    public static final String SQXX_TZ_YTH_SLZT = "sqxx.tz.yth.slzt";
    /**
     * 申请信息台账--已退回只根据受理状态查询
     */
    public static final String SQXX_TZ_YTH_ONLYBYSLZT = "sqxx.tz.yth.onlybyslzt";
    /**
     * 申请信息台账办件数量统计状态
     */
    public static final String SQXX_TZ_BJ_SLZT = "sqxx.tz.bj.slzt";
    /**
     * 申请信息预审台账受理状态--预审
     */
    public static final String SQXX_TZ_YS_SLZT = "sqxx.tz.ys.slzt";
    /**
     * 申请信息预审台账受理状态--复审
     */
    public static final String SQXX_TZ_FS_SLZT = "sqxx.tz.fs.slzt";
    /**
     * 申请信息预审台账受理状态--银行盖章
     */
    public static final String SQXX_TZ_GZ_SLZT = "sqxx.tz.gz.slzt";
    /**
     * 申请信息台账受理状态--云受理
     */
    public static final String SQXX_TZ_YSL_SLZT = "sqxx.tz.ysl.slzt";
    /**
     * 申请信息台账受理状态--全部
     */
    public static final String SQXX_TZ_ALL_SLZT = "sqxx.tz.all.slzt";
    /**
     * 申请信息登记费台账受理状态
     */
    public static final String SQXX_DJF_TZ_SLZT = "sqxx.djf.tz.slzt";

    /**
     * 申请信息台账受理状态--待认领
     */
    public static final String SQXX_TZ_DRL_SLZT = "sqxx.tz.drl.slzt";
    /**
     * 申请信息台账受理状态--认领待办
     */
    public static final String SQXX_TZ_RLDB_SLZT = "sqxx.tz.rldb.slzt";
    /**
     * 申请信息台账受理状态--认领已办
     */
    public static final String SQXX_TZ_RLYB_SLZT = "sqxx.tz.rlyb.slzt";
    /**
     * 申请信息台账受理状态--认领项目列表
     */
    public static final String SQXX_TZ_RLXMLB_SLZT = "sqxx.tz.rlxmlb.slzt";
    /**
     * 申请信息台账受理状态--部门项目列表
     */
    public static final String SQXX_TZ_BMUSER_XMLB_SLZT = "sqxx.tz.bmuser.xmlb.slzt";
    /**
     * 申请信息台账受理状态--缮证
     */
    public static final String SQXX_TZ_SZ_SLZT = "sqxx.tz.sz.slzt";
    /**
     * 申请信息缮证台账--申请类型
     */
    public static final String SQXX_TZ_SZ_SQLX = "sqxx.tz.sz.sqlx";
    /**
     * #银行复审人（fsr）
     */
    public static final String BANK_SQXX_FSR = "bank.sqxx.fsr";
    /**
     * #银行登簿人（dbr）
     */
    public static final String BANK_SQXX_DBR = "bank.sqxx.dbr";
    /**
     * #根据行政区域代码查询
     */
    public static final String QUERY_XZQYDM = "query.xzqdm";
    /**
     * 待缴费台账 只展示核税的
     */
    public static final String SQXX_TZ_DJF_HS = "sqxx.tz.djf.hs";
    /**
     * 已通过台账 展示slzt为已通过的业务
     */
    public static final String SQXX_TZ_YTG = "sqxx.tz.ytg";

    /**
     * 申请信息限制信息验证，不动产单元号重复保存是否打开原流程（0:否，1:是）
     */
    public static final String SQXX_XZXX_BDCDYBHCFBL_SFDKYLC = "xzxx.BdcdybhCfbl.sfdkylc";
    /**
     * 申请信息产权信息保存时，fczhlist是否只保存当前不动产单元的fczh
     */
    public static final String SQXX_CQXX_SAVE_FCZH_TO_FCZHLIST = "sqxx.cqxx.save.fczh.to.fczhlist";

    /**
     * 限制信息产权证不验证申请类型
     */
    public static final String XZXX_CQZH_BYZ_SQLX = "xzxx.cqzh.byz.sqlx";

    /**
     * 限制信息不动产单元号不验证申请类型
     */
    public static final String XZXX_BDCDYH_BYZ_SQLX = "xzxx.cqzh.byz.sqlx";

    /**
     * 登记费缴费方式
     */
    public static final String DJF_JFFS = "djf.jffs";
    /**
     * 有房无房查询地区范围
     */
    public static final String YFWF_CXDQFW = "yfwf.cxdqfw";
    /**
     * 线上审核
     */
    public static final String YC_XSSH = "yc.xssh";
    /**
     * 线上审核--受理人
     */
    public static final String YC_XSSH_SLR = "yc.xssh.slr";
    /**
     * 线上审核--核定人
     */
    public static final String YC_XSSH_HDR = "yc.xssh.hdr";
    /**
     * 线上审核--受理意见
     */
    public static final String YC_XSSH_SLYJ = "yc.xssh.slyj";
    /**
     * 线上审核--复审意见
     */
    public static final String YC_XSSH_FSYJ = "yc.xssh.fsyj";
    /**
     * 线上审核--核定意见
     */
    public static final String YC_XSSH_HDYJ = "yc.xssh.hdyj";
    /**
     * 保存审核中心
     */
    public static final String YC_SQXX_SAVE_SHZX = "yc.sqxx.save.shzx";
    /**
     * 验证用户授权
     */
    public static final String YC_CHECK_YHSQ = "yc.check.yhsq";
    /**
     * 产权查询显示附记
     */
    public static final String YC_CQCX_SHOW_FJ = "yc.cqcx.show.fj";
}

==> hlw-core-0.0.2-20251205.085720-174-sources.jar: cn/gtmap/hlw/core/constant/pzx/SqxxPzxKeyConstant.java <==
package cn.gtmap.hlw.core.constant.pzx;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/19 10:56
 * @description 申请信息配置项
 */
public class SqxxPzxKeyConstant {

    /**
     * 可删除的SLTZ
     */
    public static final String APPLY_DELETE_SLZT = "apply.delete.slzt";

    /**
     * 是否分别持证
     */
    public static final String SQXX_SFFBCZ = "sqxx.sffbcz";

    /**
     * 申请信息合同信息保存时，需要去除权利人（买方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_HTXX_SAVA_REMOVE_QLR_SQLX = "sqxx.htxx.save.remove.qlr.sqlx";
    /**
     * 申请信息合同信息保存时，需要去除义务人（卖方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_HTXX_SAVA_REMOVE_YWR_SQLX = "sqxx.htxx.save.remove.ywr.sqlx";

    /**
     * 申请信息产权信息保存时，需要去除权利人（买方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_CQXX_SAVA_REMOVE_QLR_SQLX = "sqxx.cqxx.save.remove.qlr.sqlx";
    /**
     * 申请信息产权信息保存时，需要去除义务人（卖方信息的申请类型）,逗号相隔
     */
    public static final String SQXX_CQXX_SAVA_REMOVE_YWR_SQLX = "sqxx.cqxx.save.remove.ywr.sqlx";

    /**
     * 申请信息台账受理状态--待提交
     */
    public static final String SQXX_TZ_DTJ_SLZT = "sqxx.tz.dtj.slzt";
    /**
     * 申请信息台账受理状态--待缴费
     */
    public static final String SQXX_TZ_DJF_SLZT = "sqxx.tz.djf.slzt";
    /**
     * 申请信息台账受理状态--草稿
     */
    public static final String SQXX_TZ_CG_SLZT = "sqxx.tz.cg.slzt";
    /**
     * 申请信息台账受理状态--审核中
     */
    public static final String SQXX_TZ_SHZ_SLZT = "sqxx.tz.shz.slzt";
    /**
     * 申请信息审核通过台账受理状态
     */
    public static final String SQXX_TZ_SHTG_SLZT = "sqxx.tz.shtg.slzt";
    /**
     * 复核工作量查询台账受理状态
     */
    public static final String SQXX_TZ_FHGZL_SLZT = "sqxx.tz.fhgzl.slzt";
    /**
     * 登记资料查询申请台账受理状态
     */
    public static final String SQXX_TZ_DJZLCXSQ_SLZT = "sqxx.tz.djzlcxsq.slzt";
    /**
     * 镇江盖章台账-不需要云签的sqlx
     */
    public static final String SQXX_TZ_NOTYQ_SQLX = "sqxx.tz.notyq.sqlx";
    /**
     * 银行核验台账申请类型
     */
    public static final String SQXX_TZ_YHHY_SQLX = "sqxx.tz.yhhy.sqlx";
    /**
     * 申请信息台账受理状态--已退回
     */
    public static final String SQXX_TZ_YTH_SLZT = "sqxx.tz.yth.slzt";
    /**
     * 申请信息台账--已退回只根据受理状态查询
     */
    public static final String SQXX_TZ_YTH_ONLYBYSLZT = "sqxx.tz.yth.onlybyslzt";
    /**
     * 申请信息台账办件数量统计状态
     */
    public static final String SQXX_TZ_BJ_SLZT = "sqxx.tz.bj.slzt";
    /**
     * 申请信息预审台账受理状态--预审
     */
    public static final String SQXX_TZ_YS_SLZT = "sqxx.tz.ys.slzt";
    /**
     * 申请信息预审台账优先展示受理状态--预审
     */
    public static final String SQXX_TZ_YS_YXZS_SLZT = "sqxx.tz.ys.yxzs.slzt";
    /**
     * 申请信息预审台账受理状态--复审
     */
    public static final String SQXX_TZ_FS_SLZT = "sqxx.tz.fs.slzt";
    /**
     * 申请信息预审台账受理状态--银行盖章
     */
    public static final String SQXX_TZ_GZ_SLZT = "sqxx.tz.gz.slzt";
    /**
     * 申请信息台账受理状态--云受理
     */
    public static final String SQXX_TZ_YSL_SLZT = "sqxx.tz.ysl.slzt";
    /**
     * 申请信息台账受理状态--全部
     */
    public static final String SQXX_TZ_ALL_SLZT = "sqxx.tz.all.slzt";
    /**
     * 申请信息登记费台账受理状态
     */
    public static final String SQXX_DJF_TZ_SLZT = "sqxx.djf.tz.slzt";

    /**
     * 申请信息台账受理状态--待认领
     */
    public static final String SQXX_TZ_DRL_SLZT = "sqxx.tz.drl.slzt";
    /**
     * 申请信息台账受理状态--认领待办
     */
    public static final String SQXX_TZ_RLDB_SLZT = "sqxx.tz.rldb.slzt";
    /**
     * 申请信息台账受理状态--认领已办
     */
    public static final String SQXX_TZ_RLYB_SLZT = "sqxx.tz.rlyb.slzt";
    /**
     * 申请信息台账受理状态--认领项目列表
     */
    public static final String SQXX_TZ_RLXMLB_SLZT = "sqxx.tz.rlxmlb.slzt";
    /**
     * 申请信息台账受理状态--部门项目列表
     */
    public static final String SQXX_TZ_BMUSER_XMLB_SLZT = "sqxx.tz.bmuser.xmlb.slzt";
    /**
     * 申请信息台账受理状态--缮证
     */
    public static final String SQXX_TZ_SZ_SLZT = "sqxx.tz.sz.slzt";
    /**
     * 申请信息缮证台账--申请类型
     */
    public static final String SQXX_TZ_SZ_SQLX = "sqxx.tz.sz.sqlx";
    /**
     * #银行复审人（fsr）
     */
    public static final String BANK_SQXX_FSR = "bank.sqxx.fsr";
    /**
     * #银行登簿人（dbr）
     */
    public static final String BANK_SQXX_DBR = "bank.sqxx.dbr";
    /**
     * #根据行政区域代码查询
     */
    public static final String QUERY_XZQYDM = "query.xzqdm";
    /**
     * 待缴费台账 只展示核税的
     */
    public static final String SQXX_TZ_DJF_HS = "sqxx.tz.djf.hs";
    /**
     * 已通过台账 展示slzt为已通过的业务
     */
    public static final String SQXX_TZ_YTG = "sqxx.tz.ytg";

    /**
     * 申请信息限制信息验证，不动产单元号重复保存是否打开原流程（0:否，1:是）
     */
    public static final String SQXX_XZXX_BDCDYBHCFBL_SFDKYLC = "xzxx.BdcdybhCfbl.sfdkylc";
    /**
     * 申请信息产权信息保存时，fczhlist是否只保存当前不动产单元的fczh
     */
    public static final String SQXX_CQXX_SAVE_FCZH_TO_FCZHLIST = "sqxx.cqxx.save.fczh.to.fczhlist";

    /**
     * 限制信息产权证不验证申请类型
     */
    public static final String XZXX_CQZH_BYZ_SQLX = "xzxx.cqzh.byz.sqlx";

    /**
     * 限制信息不动产单元号不验证申请类型
     */
    public static final String XZXX_BDCDYH_BYZ_SQLX = "xzxx.cqzh.byz.sqlx";

    /**
     * 登记费缴费方式
     */
    public static final String DJF_JFFS = "djf.jffs";
    /**
     * 有房无房查询地区范围
     */
    public static final String YFWF_CXDQFW = "yfwf.cxdqfw";
    /**
     * 线上审核
     */
    public static final String YC_XSSH = "yc.xssh";
    /**
     * 线上审核--受理人
     */
    public static final String YC_XSSH_SLR = "yc.xssh.slr";
    /**
     * 线上审核--核定人
     */
    public static final String YC_XSSH_HDR = "yc.xssh.hdr";
    /**
     * 线上审核--受理意见
     */
    public static final String YC_XSSH_SLYJ = "yc.xssh.slyj";
    /**
     * 线上审核--复审意见
     */
    public static final String YC_XSSH_FSYJ = "yc.xssh.fsyj";
    /**
     * 线上审核--核定意见
     */
    public static final String YC_XSSH_HDYJ = "yc.xssh.hdyj";
    /**
     * 保存审核中心
     */
    public static final String YC_SQXX_SAVE_SHZX = "yc.sqxx.save.shzx";
    /**
     * 验证用户授权
     */
    public static final String YC_CHECK_YHSQ = "yc.check.yhsq";
    /**
     * 产权查询显示附记
     */
    public static final String YC_CQCX_SHOW_FJ = "yc.cqcx.show.fj";
    /**
     * 可以查看创建部门是本部门及下属部门的角色
     */
    public static final String YC_CK_BBMJXSBM_ROLE = "yc.ck.bbmjxsbm.role";
}
